@@ -12,11 +12,9 @@ sub paste {
     channel => $self->channel || '',
     nick    => $self->name || '',
     paste   => $self->text,
-    summary => $self->description || '',
+    summary => $self->desc || '',
   });
 
-  say $tx->res->body;
-
   unless ($tx->res->is_status_class(200)) {
     say $tx->res->message;
     say $tx->res->body;
